summaryrefslogtreecommitdiff
path: root/test/unit/expr/expr_white.h
diff options
context:
space:
mode:
Diffstat (limited to 'test/unit/expr/expr_white.h')
-rw-r--r--test/unit/expr/expr_white.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/unit/expr/expr_white.h b/test/unit/expr/expr_white.h
index 3da360126..6b48d66e6 100644
--- a/test/unit/expr/expr_white.h
+++ b/test/unit/expr/expr_white.h
@@ -1,4 +1,4 @@
/* White box testing of CVC4::Expr. */
#include <cxxtest/TestSuite.h>
@@ -10,10 +10,10 @@ class ExprWhite : public CxxTest::TestSuite {
public:
void testNull() {
- Expr::s_null;
+ Node::s_null;
}
void testCopyCtor() {
- Expr e(Expr::s_null);
+ Node e(Node::s_null);
}
};
generated by cgit on debian on lair
@@ -1,4 +1,4 @@
-/* White box testing of CVC4::Expr. */
+/* White box testing of CVC4::Node. */
#include <cxxtest/TestSuite.h>
contact matthew@masot.net with questions or feedback